@@ -359,11 +359,20 @@ Replaced with B<nchunks>
 =head1 SEE ALSO
 
 Finnigan::ProfileChunk
+
 Finnigan::PacketHeader
+
 Finnigan::Scan
+
 Finnigan::Scan::Profile
+
 Finnigan::ScanEvent
 
+Finnigan::ScanIndexEntry
+
+L<uf-scan>
+
+
 =head1 AUTHOR
 
 Gene Selkov, E<lt>selkovjr@gmail.comE<gt>
